@@ -1,32 +1,26 @@
 #' Delete an edge from an existing graph object
-#' @description From a graph object of class
-#' \code{dgr_graph}, delete an existing edge by
-#' specifying either: (1) a pair of node IDs
-#' corresponding to the edge (keeping into
-#' consideration the direction of the edge in
-#' a directed graph), or (2) an edge ID.
-#' @param graph a graph object of class
-#' \code{dgr_graph}.
-#' @param from a node ID from which the edge to be
-#' removed is outgoing. If an edge ID is provided to
-#' \code{id}, then this argument is ignored. There
-#' is the option to use a node \code{label}
-#' value here (and this must correspondingly also be
-#' done for the \code{to} argument) for defining
-#' node connections. Note that this is only possible
-#' if all nodes have distinct \code{label} values set
-#' and none exist as an empty string.
-#' @param to a node ID to which the edge to be removed
-#' is incoming. If an edge ID is provided to
-#' \code{id}, then this argument is ignored. There
-#' is the option to use a node \code{label}
-#' value here (and this must correspondingly also be
-#' for the \code{from} argument) for defining
-#' node connections. Note that this is only possible
-#' if all nodes have distinct \code{label} values set
-#' and none exist as an empty string.
+#'
+#' From a graph object of class `dgr_graph`, delete an existing edge by
+#'   specifying either: (1) a pair of node IDs corresponding to the edge
+#'   (keeping into consideration the direction of the edge in a directed graph),
+#'   or (2) an edge ID.
+#' @inheritParams render_graph
+#' @param from a node ID from which the edge to be removed is outgoing. If an
+#'   edge ID is provided to `id`, then this argument is ignored. There is
+#'   the option to use a node `label` value here (and this must
+#'   correspondingly also be done for the `to` argument) for defining node
+#'   connections. Note that this is only possible if all nodes have distinct
+#'   `label` values set and none exist as an empty string.
+#' @param to a node ID to which the edge to be removed is incoming. If an edge
+#'   ID is provided to `id`, then this argument is ignored. There is the
+#'   option to use a node `label` value here (and this must correspondingly
+#'   also be for the `from` argument) for defining node connections. Note
+#'   that this is only possible if all nodes have distinct `label` values
+#'   set and none exist as an empty string.
 #' @param id an edge ID of the edge to be removed.
-#' @return a graph object of class \code{dgr_graph}.
+#'
+#' @return A graph object of class `dgr_graph`.
+#'
 #' @examples
 #' # Create a graph with 2 nodes
 #' graph <-
@@ -48,8 +42,7 @@
 #'     to = 2)
 #'
 #' # Get the count of edges in the graph
-#' graph %>%
-#'   count_edges()
+#' graph %>% count_edges()
 #'
 #' # Create an undirected graph with
 #' # 2 nodes and an edge
@@ -96,9 +89,8 @@
 #'     from = "one",
 #'     to = "two") %>%
 #'   count_edges()
-#' @importFrom dplyr filter select
-#' @export delete_edge
-
+#'
+#' @export
 delete_edge <- function(graph,
                         from = NULL,
                         to = NULL,
@@ -134,9 +126,6 @@ delete_edge <- function(graph,
       reasons = "The graph contains no edges")
   }
 
-  # Create bindings for specific variables
-  label <- NULL
-
   # If a value is supplied for `id`, determine which
   # node ID values the edge ID references
   if (!is.null(id)) {
