@@ -1,22 +1,17 @@
 #' Get an aggregate value from the outdegree of nodes
-#' @description Get a single,
-#' aggregate value from the
-#' outdegree values for all nodes
-#' in a graph, or, a subset
-#' of graph nodes.
-#' @param graph a graph object of
-#' class \code{dgr_graph}.
-#' @param agg the aggregation
-#' function to use for summarizing
-#' outdegree values from graph nodes.
-#' The following aggregation functions
-#' can be used: \code{sum}, \code{min},
-#' \code{max}, \code{mean}, or \code{median}.
-#' @param conditions an option to
-#' use filtering conditions for
-#' the nodes to consider.
-#' @return a vector with an aggregate
-#' outdegree value.
+#'
+#' Get a single, aggregate value from the outdegree values for all nodes in a
+#' graph, or, a subset of graph nodes.
+#'
+#' @inheritParams render_graph
+#' @param agg The aggregation function to use for summarizing outdegree values
+#'   from graph nodes. The following aggregation functions can be used: `sum`,
+#'   `min`, `max`, `mean`, or `median`.
+#' @param conditions An option to use filtering conditions for the nodes to
+#'   consider.
+#'
+#' @return A vector with an aggregate outdegree value.
+#'
 #' @examples
 #' # Create a random graph using the
 #' # `add_gnm_graph()` function
@@ -54,12 +49,9 @@
 #'   get_agg_degree_out(
 #'     agg = "mean",
 #'     conditions = value < 5.0)
-#' @importFrom dplyr group_by summarize_ select filter ungroup pull
-#' @importFrom stats as.formula
-#' @importFrom purrr flatten_dbl
-#' @importFrom rlang enquo UQ get_expr
-#' @export get_agg_degree_out
-
+#'
+#' @import rlang
+#' @export
 get_agg_degree_out <- function(graph,
                                agg,
                                conditions = NULL) {
@@ -78,9 +70,6 @@ get_agg_degree_out <- function(graph,
   # Capture provided conditions
   conditions <- rlang::enquo(conditions)
 
-  # Create binding for variable
-  id <- NULL
-
   # If filtering conditions are provided then
   # pass in those conditions and filter the ndf
   if (!is.null(
@@ -91,10 +80,7 @@ get_agg_degree_out <- function(graph,
     ndf <- get_node_df(graph)
 
     # Apply filtering conditions to the ndf
-    ndf <-
-      filter(
-        .data = ndf,
-        rlang::UQ(conditions))
+    ndf <- dplyr::filter(.data = ndf, !!conditions)
 
     # Get a vector of node ID values
     node_ids <-
