@@ -1,22 +1,20 @@
 #' Get data frames bound to node attributes
-#' @description From a graph object of class
-#' \code{dgr_graph}, get one or more data frames
-#' already bound as node and/or edge attribute
-#' values given graph node and/or edges.
-#' @param graph a graph object of class
-#' \code{dgr_graph}.
-#' @param node_id a vector of node ID values in
-#' which data frames are bound as node attrs.
-#' @param edge_id a vector of edge ID values in
-#' which data frames are bound as edge attrs.
-#' @param return_format the format in which to
-#' return the results of several data frames. These
-#' can either be: (1) \code{single_tbl} (a tibble
-#' object resulting from a `bind_rows` operation of
-#' multiple data frames), and (2) \code{single_df}
-#' (a single data frame which all of the data frame
-#' data).
-#' @return either a tibble or a data frame.
+#'
+#' From a graph object of class `dgr_graph`, get one or more data frames
+#'   already bound as node and/or edge attribute values given graph node and/or
+#'   edges.
+#' @inheritParams render_graph
+#' @param node_id a vector of node ID values in which data frames are bound as
+#'   node attrs.
+#' @param edge_id a vector of edge ID values in which data frames are bound as
+#'   edge attrs.
+#' @param return_format the format in which to return the results of several
+#'   data frames. These can either be: (1) `single_tbl` (a tibble object
+#'   resulting from a `bind_rows` operation of multiple data frames), and (2)
+#'   `single_df` (a single data frame which all of the data frame data).
+#'
+#' @return Either a tibble or a data frame.
+#'
 #' @examples
 #' # Create a node data frame (ndf)
 #' ndf <-
@@ -101,11 +99,8 @@
 #'   graph,
 #'   edge_id = 1,
 #'   return_format = "single_df")
-#' @importFrom dplyr filter select bind_rows filter starts_with
-#' @importFrom dplyr everything left_join as_tibble tibble
-#' @importFrom purrr flatten_chr
-#' @export get_attr_dfs
-
+#'
+#' @export
 get_attr_dfs <- function(graph,
                          node_id = NULL,
                          edge_id = NULL,
@@ -130,10 +125,6 @@ get_attr_dfs <- function(graph,
       reasons = "The graph contains no nodes, so, a df cannot be added")
   }
 
-  # Create bindings for specific variables
-  id <- from <- to <- type <- rel <- label <- NULL
-  df_id <- df_id__ <- id__ <- node_edge__ <-  NULL
-
   # Collect data frames that are attributes of graph nodes
   if (!is.null(node_id)) {
 
@@ -160,7 +151,7 @@ get_attr_dfs <- function(graph,
                   by = c("df_id__" = "df_id")) %>%
                 dplyr::select(-df_id__) %>%
                 dplyr::select(-id__) %>%
-                dplyr::select(node_edge__, id, type, label, everything())
+                dplyr::select(node_edge__, id, type, label, dplyr::everything())
             } else {
               dplyr::tibble()
             }})
@@ -193,7 +184,7 @@ get_attr_dfs <- function(graph,
                   by = c("df_id__" = "df_id")) %>%
                 dplyr::select(-df_id__) %>%
                 dplyr::select(-id__) %>%
-                dplyr::select(node_edge__, id, from, to, rel, everything())
+                dplyr::select(node_edge__, id, from, to, rel, dplyr::everything())
             } else {
               dplyr::tibble()
             }})
