@@ -1,17 +1,15 @@
 #' Get the count of multiple edges
-#' @description Get a count of the
-#' number of multiple edges in the
-#' graph. Included in the count is the
-#' number of separate edges that
-#' share the same edge definition
-#' (i.e., same pair of nodes) across
-#' the entire graph. So, for example,
-#' if there are 2 edge definitions in
-#' the graph that involve 6 separate
-#' edge IDs, the count will be \code{4}.
-#' @param graph a graph object of class
-#' \code{dgr_graph}.
-#' @return a vector with a single, numerical value.
+#'
+#' Get a count of the number of multiple edges in the graph. Included in the
+#' count is the number of separate edges that share the same edge definition
+#' (i.e., same pair of nodes) across the entire graph. So, for example, if there
+#' are 2 edge definitions in the graph that involve 6 separate edge IDs, the
+#' count will be `4`.
+#'
+#' @inheritParams render_graph
+#'
+#' @return A vector with a single, numerical value.
+#'
 #' @examples
 #' # Create a node data frame (ndf)
 #' ndf <-
@@ -34,11 +32,9 @@
 #' # Get the total number of multiple
 #' # edges (those edges that share an
 #' # edge definition) in the graph
-#' graph %>%
-#'   get_multiedge_count()
-#' @importFrom dplyr distinct select
-#' @export get_multiedge_count
-
+#' graph %>% get_multiedge_count()
+#'
+#' @export
 get_multiedge_count <- function(graph) {
 
   # Get the name of the function
@@ -60,9 +56,6 @@ get_multiedge_count <- function(graph) {
       reasons = "The graph contains no edges")
   }
 
-  # Create bindings for specific variables
-  from <- to <- NULL
-
   # Check for the number of multiple edges
   # regardless of which definitions these
   # edges have
