@@ -1,45 +1,32 @@
 #' Layout nodes using a text-based schematic
-#' @description Layout one or several groups of
-#' nodes using a text-based schematic. The option
-#' is available to apply sorting to each of the
-#' groups.
-#' @param graph a graph object of class
-#' \code{dgr_graph}.
-#' @param layout a layout character string that
-#' provides a schematic for the layout. This
-#' consists of a rectangular collection of
-#' \code{-} characters (for no node placement),
-#' and numbers from \code{1} to \code{9}
-#' (representing different groupings of nodes,
-#' further described in the \code{nodes} argument).
-#' @param nodes a named vector of the form:
-#' \code{c("1" = "[node_attr]:[value]", ...)}. The
-#' LHS corresponds to the numbers used in the
-#' \code{layout} schematic. The RHS provides a
-#' shorthand for the node attribute and a value
-#' for grouping together nodes (separated by a
-#' colon). For instance, with \code{"type:a"} in the
-#' RHS (and \code{"1"} in the LHS) we would target
-#' all nodes with a \code{type} attribute equal
-#' to \code{a} for positioning in the graph as
-#' described by the \code{1}s in the \code{layout}.
-#' @param sort an optional sorting method to apply
-#' to the collection of nodes before assigning
-#' positional information. Like \code{nodes}, this
-#' is a named vector of the form:
-#' \code{c("1" = "[node_attr]:asc|desc", ...)}.
-#' The \code{node_attr} in this case should be
-#' different than that used in \code{nodes}. Ideally,
-#' this node attribute should have unique values.
-#' Choose either \code{asc} or \code{desc} right of
-#' the colon for ascending or descending sorts.
-#' @param width the width of the \code{layout}
-#' diagram.
-#' @param height the height of the \code{layout}
-#' diagram.
-#' @param ll a vector describing the the lower-left
-#' coordinates of the \code{layout}
-#' @return a graph object of class \code{dgr_graph}.
+#'
+#' Layout one or several groups of nodes using a text-based schematic. The
+#' option is available to apply sorting to each of the groups.
+#'
+#' @inheritParams render_graph
+#' @param layout A layout character string that provides a schematic for the
+#'   layout. This consists of a rectangular collection of `-` characters (for no
+#'   node placement), and numbers from `1` to `9` (representing different
+#'   groupings of nodes, further described in the `nodes` argument).
+#' @param nodes A named vector of the form: `c("1" = "[node_attr]:[value]",
+#'   ...)`. The LHS corresponds to the numbers used in the `layout` schematic.
+#'   The RHS provides a shorthand for the node attribute and a value for
+#'   grouping together nodes (separated by a colon). For instance, with
+#'   `"type:a"` in the RHS (and `"1"` in the LHS) we would target all nodes with
+#'   a `type` attribute equal to `a` for positioning in the graph as described
+#'   by the `1`s in the `layout`.
+#' @param sort An optional sorting method to apply to the collection of nodes
+#'   before assigning positional information. Like `nodes`, this is a named
+#'   vector of the form: `c("1" = "[node_attr]:asc|desc", ...)`. The `node_attr`
+#'   in this case should be different than that used in `nodes`. Ideally, this
+#'   node attribute should have unique values. Choose either `asc` or `desc`
+#'   right of the colon for ascending or descending sorts.
+#' @param width The width of the `layout` diagram.
+#' @param height The height of the `layout` diagram.
+#' @param ll A vector describing the the lower-left coordinates of the `layout`
+#'
+#' @return A graph object of class `dgr_graph`.
+#'
 #' @examples
 #' # Create a graph with unique labels and
 #' # several node `type` groupings
@@ -88,20 +75,9 @@
 #' # Show the graph's node data frame
 #' # to confirm that `x` and `y` values
 #' # were added to each of the nodes
-#' get_node_df(graph)
-#' #>   id type label x y
-#' #> 1  1    a     a 0 8
-#' #> 2  2    a     b 0 6
-#' #> 3  3    b     c 5 4
-#' #> 4  4    b     d 4 4
-#' #> 5  5    b     e 3 4
-#' #> 6  6    c     f 8 0
-#' #> 7  7    c     g 8 2
-#' @importFrom stringr str_split
-#' @importFrom tibble tibble
-#' @importFrom dplyr bind_rows bind_cols filter_ arrange_ left_join
-#' @export layout_nodes_w_string
-
+#' graph %>% get_node_df()
+#'
+#' @export
 layout_nodes_w_string <- function(graph,
                                   layout,
                                   nodes,
@@ -113,9 +89,15 @@ layout_nodes_w_string <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Get the graph's internal node data frame
@@ -146,7 +128,10 @@ layout_nodes_w_string <- function(graph,
 
   # Stop function if not all rows are of equal length
   if (mean(layout_row_length) != layout_row_length[1]) {
-    stop("Each row must have the same length.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "Each row must have the same length")
   }
 
   layout_column_number <- layout_row_length <- layout_row_length[1]
@@ -157,14 +142,14 @@ layout_nodes_w_string <- function(graph,
   x_pts <- seq(0, width, width/(layout_column_number - 1)) + ll[1]
   y_pts <- rev(seq(0, height, height/(layout_row_number - 1))) + ll[2]
 
-  # Create tibble called `ndf_parts`
-  ndf_parts <- tibble::tibble()
+  # Create a tibble called `ndf_parts`
+  ndf_parts <- dplyr::tibble()
 
   for (k in 1:node_group_count) {
 
     # Create table with position and node ID
     position_table <-
-      tibble::tibble(
+      dplyr::tibble(
         x = as.numeric(NA),
         y = as.numeric(NA))
 
@@ -185,7 +170,7 @@ layout_nodes_w_string <- function(graph,
         if (unlist(stringr::str_split(layout[i], ""))[j] == k) {
 
           item_table <-
-            tibble::tibble(
+            dplyr::tibble(
               x = x_pts[j],
               y = y_pts[i])
 
@@ -245,7 +230,7 @@ layout_nodes_w_string <- function(graph,
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "layout_nodes_w_string",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
