@@ -1,33 +1,38 @@
 #' Rename a node attribute
-#' @description Within a graph's internal node data
-#' frame (ndf), rename an existing node attribute.
-#' @param graph a graph object of class
-#' \code{dgr_graph}.
-#' @param node_attr_from the name of the node attribute
-#' that will be renamed.
-#' @param node_attr_to the new name of the node
-#' attribute column identified in \code{node_attr_from}.
-#' @return a graph object of class \code{dgr_graph}.
+#'
+#' Within a graph's internal node data frame (ndf), rename an existing node
+#' attribute.
+#'
+#' @inheritParams render_graph
+#' @param node_attr_from The name of the node attribute that will be renamed.
+#' @param node_attr_to The new name of the node attribute column identified in
+#'   `node_attr_from`.
+#'
+#' @return A graph object of class `dgr_graph`.
+#'
 #' @examples
-#' # Create a random graph
+#' # Create a random graph using the
+#' # `add_gnm_graph()` function
 #' graph <-
-#'   create_random_graph(
-#'     n = 5, m = 10,
+#'   create_graph() %>%
+#'   add_gnm_graph(
+#'     n = 5,
+#'     m = 8,
 #'     set_seed = 23) %>%
 #'   set_node_attrs(
 #'     node_attr = shape,
-#'     values = "circle")
+#'     values = "circle") %>%
+#'   set_node_attrs(
+#'     node_attr = value,
+#'     values = rnorm(
+#'       n = count_nodes(.),
+#'       mean = 5,
+#'       sd = 1) %>% round(1))
 #'
 #' # Get the graph's internal ndf
 #' # to show which node attributes
 #' # are available
-#' get_node_df(graph)
-#' #>   id type label value  shape
-#' #> 1  1 <NA>     1   6.0 circle
-#' #> 2  2 <NA>     2   2.5 circle
-#' #> 3  3 <NA>     3   3.5 circle
-#' #> 4  4 <NA>     4   7.5 circle
-#' #> 5  5 <NA>     5   8.5 circle
+#' graph %>% get_node_df()
 #'
 #' # Rename the `value` node
 #' # attribute as `weight`
@@ -40,16 +45,10 @@
 #' # Get the graph's internal
 #' # ndf to show that the node
 #' # attribute had been renamed
-#' get_node_df(graph)
-#' #>   id type label weight  shape
-#' #> 1  1 <NA>     1    6.0 circle
-#' #> 2  2 <NA>     2    2.5 circle
-#' #> 3  3 <NA>     3    3.5 circle
-#' #> 4  4 <NA>     4    7.5 circle
-#' #> 5  5 <NA>     5    8.5 circle
-#' @importFrom rlang enquo UQ
-#' @export rename_node_attrs
-
+#' graph %>% get_node_df()
+#'
+#' @import rlang
+#' @export
 rename_node_attrs <- function(graph,
                               node_attr_from,
                               node_attr_to) {
@@ -57,26 +56,40 @@ rename_node_attrs <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
-  node_attr_from <- rlang::enquo(node_attr_from)
-  node_attr_from <- (rlang::UQ(node_attr_from) %>% paste())[2]
-
-  node_attr_to <- rlang::enquo(node_attr_to)
-  node_attr_to <- (rlang::UQ(node_attr_to) %>% paste())[2]
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
 
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Validation: Graph contains nodes
   if (graph_contains_nodes(graph) == FALSE) {
-    stop("The graph contains no nodes, so, no node attributes can be renamed.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph contains no nodes")
   }
 
+  # Get the requested `node_attr_from`
+  node_attr_from <-
+    rlang::enquo(node_attr_from) %>% rlang::get_expr() %>% as.character()
+
+  # Get the requested `node_attr_to`
+  node_attr_to <-
+    rlang::enquo(node_attr_to) %>% rlang::get_expr() %>% as.character()
+
   # Stop function if `node_attr_from` and
   # `node_attr_to` are identical
   if (node_attr_from == node_attr_to) {
-    stop("You cannot rename using the same name.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "You cannot rename using the same name")
   }
 
   # Stop function if `node_attr_to` is `id` or any
@@ -84,14 +97,20 @@ rename_node_attrs <- function(graph,
   if (any(unique(c("id",
                    colnames(get_node_df(graph)))) %in%
           node_attr_to)) {
-    stop("You cannot use that name for `node_attr_to`.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "You cannot use that name for `node_attr_to`")
   }
 
   # Stop function if `node_attr_from` is `id`, `label`
   # or `type`
   if (any(c("id", "label", "type") %in%
           node_attr_from)) {
-    stop("You cannot use that name for `node_attr_from`.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "You cannot use that name for `node_attr_from`")
   }
 
   # Get the number of nodes ever created for
@@ -107,7 +126,10 @@ rename_node_attrs <- function(graph,
   # Stop function if `node_attr_from` is not one
   # of the graph's columns
   if (!any(column_names_graph %in% node_attr_from)) {
-    stop("The node attribute to rename is not in the ndf.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The node attribute to rename is not in the ndf")
   }
 
   # Set the column name for the renamed attr
@@ -126,7 +148,7 @@ rename_node_attrs <- function(graph,
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "rename_node_attrs",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
