@@ -1,11 +1,11 @@
 #' Save a graph or graph series to disk
-#' @description Save a graph or a graph series object
-#' to disk.
-#' @param x a graph object of class \code{dgr_graph}
-#' or a graph series object of type \code{dgr_graph_1D}.
-#' @param file a file name for the graph or
-#' graph series. Provide a character string and the
-#' \code{.dgr} extension will be applied to it.
+#'
+#' Save a graph or a graph series object to disk.
+#'
+#' @param x A graph object of class `dgr_graph` or a graph series object of type
+#'   `dgr_graph_1D`.
+#' @param file A file name for the graph or graph series. Provide a character
+#'   string and the `.dgr` extension will be applied to it.
 #' @examples
 #' # Create an undirected GNP
 #' # graph with 100 nodes using
@@ -19,22 +19,30 @@
 #'
 #' # Save the graph to disk; use
 #' # the file name `gnp_graph.dgr`
-#' save_graph(
-#'   x = gnp_graph,
-#'   file = "gnp_graph")
+#' # save_graph(
+#' #   x = gnp_graph,
+#' #   file = "gnp_graph"
+#' # )
 #'
 #' # To read the graph file from
 #' # disk, use `open_graph()`
-#' gnp_graph_2 <-
-#'   open_graph(
-#'     file = "gnp_graph.dgr")
-#' @export save_graph
-
+#' # gnp_graph_2 <-
+#' #   open_graph(
+#' #     file = "gnp_graph.dgr"
+#' # )
+#'
+#' @export
 save_graph <- function(x,
                        file) {
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   if (!inherits(file, "character")) {
-    stop("Provide a character string for the file.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "Provide a character string for the file")
   }
 
   if (inherits(x, "dgr_graph") |
@@ -47,6 +55,9 @@ save_graph <- function(x,
     saveRDS(x, file = file_name, compress = "xz")
 
   } else {
-    stop("The object provided is not a graph or graph series.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The object provided is not a graph or graph series")
   }
 }
