@@ -1,11 +1,13 @@
 #' Select the last set of edges created in a graph
-#' @description Select the last edges that were created
-#' in a graph object of class \code{dgr_graph}. This
-#' function should ideally be used just after creating
-#' the edges to be selected.
-#' @param graph a graph object of class
-#' \code{dgr_graph}.
-#' @return a graph object of class \code{dgr_graph}.
+#'
+#' Select the last edges that were created in a graph object of class
+#' `dgr_graph`. This function should ideally be used just after creating the
+#' edges to be selected.
+#'
+#' @inheritParams render_graph
+#'
+#' @return A graph object of class `dgr_graph`.
+#'
 #' @examples
 #' # Create a graph and add a cycle and then
 #' # a tree in 2 separate function calls
@@ -31,12 +33,9 @@
 #'
 #' # Display the graph's internal edge
 #' # data frame to verify the change
-#' graph %>%
-#'   get_edge_df()
-#' @importFrom dplyr mutate filter select pull if_else
-#' @importFrom utils tail
-#' @export select_last_edges_created
-
+#' graph %>% get_edge_df()
+#'
+#' @export
 select_last_edges_created <- function(graph) {
 
   # Get the time of function start
@@ -61,11 +60,6 @@ select_last_edges_created <- function(graph) {
       reasons = "The graph contains no edges")
   }
 
-  # Create bindings for specific variables
-  function_used <- edges <- step_created_edges <- NULL
-  step_deleted_edges <- step_init_with_edges <- version_id <- NULL
-  time_modified <- duration <- id <- NULL
-
   graph_transform_steps <-
     graph$graph_log %>%
     dplyr::mutate(step_created_edges = dplyr::if_else(
@@ -82,7 +76,7 @@ select_last_edges_created <- function(graph) {
   if (nrow(graph_transform_steps) > 0) {
 
     if (graph_transform_steps %>%
-        tail(1) %>%
+        utils::tail(1) %>%
         dplyr::pull(step_deleted_edges) == 1) {
 
       emit_error(
@@ -94,11 +88,11 @@ select_last_edges_created <- function(graph) {
         number_of_edges_created <-
           (graph_transform_steps %>%
              dplyr::select(edges) %>%
-             tail(2) %>%
+             utils::tail(2) %>%
              dplyr::pull(edges))[2] -
           (graph_transform_steps %>%
              dplyr::select(edges) %>%
-             tail(2) %>%
+             utils::tail(2) %>%
              dplyr::pull(edges))[1]
       } else {
         number_of_edges_created <-
@@ -110,7 +104,7 @@ select_last_edges_created <- function(graph) {
     edge_id_values <-
       graph$edges_df %>%
       dplyr::select(id) %>%
-      tail(number_of_edges_created) %>%
+      utils::tail(number_of_edges_created) %>%
       dplyr::pull(id)
   } else {
     edge_id_values <- NA
