@@ -1,11 +1,13 @@
 #' Select the last set of nodes created in a graph
-#' @description Select the last nodes that were created
-#' in a graph object of class \code{dgr_graph}. This
-#' function should ideally be used just after creating
-#' the nodes to be selected.
-#' @param graph a graph object of class
-#' \code{dgr_graph}.
-#' @return a graph object of class \code{dgr_graph}.
+#'
+#' Select the last nodes that were created in a graph object of class
+#' `dgr_graph`. This function should ideally be used just after creating the
+#' nodes to be selected.
+#'
+#' @inheritParams render_graph
+#'
+#' @return A graph object of class `dgr_graph`.
+#'
 #' @examples
 #' # Create a graph and add 4 nodes
 #' # in 2 separate function calls
@@ -33,12 +35,9 @@
 #'
 #' # Display the graph's internal node
 #' # data frame to verify the change
-#' graph %>%
-#'   get_node_df()
-#' @importFrom dplyr mutate filter select pull if_else
-#' @importFrom utils tail
-#' @export select_last_nodes_created
-
+#' graph %>% get_node_df()
+#'
+#' @export
 select_last_nodes_created <- function(graph) {
 
   # Get the time of function start
@@ -63,11 +62,6 @@ select_last_nodes_created <- function(graph) {
       reasons = "The graph contains no nodes")
   }
 
-  # Create bindings for specific variables
-  function_used <- nodes <- step_created_nodes <- NULL
-  step_deleted_nodes <- step_init_with_nodes <- version_id <- NULL
-  time_modified <- duration <- id <- NULL
-
   graph_transform_steps <-
     graph$graph_log %>%
     dplyr::mutate(step_created_nodes = dplyr::if_else(
@@ -84,7 +78,7 @@ select_last_nodes_created <- function(graph) {
   if (nrow(graph_transform_steps) > 0) {
 
     if (graph_transform_steps %>%
-        tail(1) %>%
+        utils::tail(1) %>%
         dplyr::pull(step_deleted_nodes) == 1) {
 
       emit_error(
@@ -96,11 +90,11 @@ select_last_nodes_created <- function(graph) {
         number_of_nodes_created <-
           (graph_transform_steps %>%
              dplyr::select(nodes) %>%
-             tail(2) %>%
+             utils::tail(2) %>%
              dplyr::pull(nodes))[2] -
           (graph_transform_steps %>%
              dplyr::select(nodes) %>%
-             tail(2) %>%
+             utils::tail(2) %>%
              dplyr::pull(nodes))[1]
       } else {
         number_of_nodes_created <-
@@ -112,7 +106,7 @@ select_last_nodes_created <- function(graph) {
     node_id_values <-
       graph$nodes_df %>%
       dplyr::select(id) %>%
-      tail(number_of_nodes_created) %>%
+      utils::tail(number_of_nodes_created) %>%
       dplyr::pull(id)
   } else {
     node_id_values <- NA
