@@ -1,18 +1,17 @@
 #' Set a data frame as a node attribute
-#' @description From a graph object of class
-#' \code{dgr_graph}, bind a data frame as a node
-#' attribute property for one given graph node. The
-#' data frames are stored in list columns within
-#' a \code{df_tbl} object. A \code{df_id} value is
-#' generated and serves as a pointer to the table
-#' row that contains the ingested data frame.
-#' @param graph a graph object of class
-#' \code{dgr_graph}.
-#' @param node the node ID to which the data frame
-#' will be bound as an attribute.
-#' @param df the data frame to be bound to the
-#' node as an attribute.
-#' @return a graph object of class \code{dgr_graph}.
+#'
+#' From a graph object of class `dgr_graph`, bind a data frame as a node
+#' attribute property for one given graph node. The data frames are stored in
+#' list columns within a `df_tbl` object. A `df_id` value is generated and
+#' serves as a pointer to the table row that contains the ingested data frame.
+#'
+#' @inheritParams render_graph
+#' @param node The node ID to which the data frame will be bound as an
+#'   attribute.
+#' @param df The data frame to be bound to the node as an attribute.
+#'
+#' @return A graph object of class `dgr_graph`.
+#'
 #' @examples
 #' # Create a node data frame (ndf)
 #' ndf <-
@@ -66,10 +65,8 @@
 #'   set_df_as_node_attr(
 #'     node = 2,
 #'     df = df_2)
-#' @importFrom dplyr filter everything mutate select bind_rows as_tibble
-#' @importFrom purrr flatten_chr
-#' @export set_df_as_node_attr
-
+#'
+#' @export
 set_df_as_node_attr <- function(graph,
                                 node,
                                 df) {
@@ -113,9 +110,6 @@ set_df_as_node_attr <- function(graph,
       reasons = "The value given for `node` does not correspond to a node ID")
   }
 
-  # Create bindings for specific variables
-  df_id__ <- node_edge__ <- id__ <- NULL
-
   # Generate an empty `df_storage` list if not present
   # TODO: put this in `create_graph()`
   if (is.null(graph$df_storage)) {
@@ -137,7 +131,7 @@ set_df_as_node_attr <- function(graph,
       df_id__ = df_id,
       node_edge__ = "node",
       id__ = node) %>%
-    dplyr::select(df_id__, node_edge__, id__, everything()) %>%
+    dplyr::select(df_id__, node_edge__, id__, dplyr::everything()) %>%
     dplyr::as_tibble()
 
   # If there is an existing data frame attributed
