@@ -1,40 +1,44 @@
-#' Traverse from one or more selected edges onto
-#' adjacent, inward nodes
-#' @description From a graph object of class
-#' \code{dgr_graph} with an active selection of edges
-#' move with the edge direction to connected nodes,
-#' replacing the current edges in the selection with
-#' those nodes traversed to. An optional filter by
-#' node attribute can limit the set of nodes traversed
-#' to.
-#' @param graph a graph object of class
-#' \code{dgr_graph}.
-#' @param conditions an option to use filtering
-#' conditions for the traversal.
-#' @param copy_attrs_from providing an edge attribute
-#' name will copy those edge attribute values to the
-#' traversed nodes. If the edge attribute already exists,
-#' the values will be merged to the traversed nodes;
-#' otherwise, a new node attribute will be created.
-#' @param copy_attrs_as if an edge attribute name
-#' is provided in \code{copy_attrs_from}, this option
-#' will allow the copied attribute values to be
-#' written under a different node attribute name.
-#' If the attribute name provided in
-#' \code{copy_attrs_as} does not exist in the graph's
-#' ndf, the new node attribute will be created
-#' with the chosen name.
-#' @param agg if an edge attribute is provided
-#' to \code{copy_attrs_from}, then an aggregation
-#' function is required since there may be cases where
-#' multiple edge attribute values will be passed onto
-#' the traversed node(s). To pass only a single value,
-#' the following aggregation functions can be used:
-#' \code{sum}, \code{min}, \code{max}, \code{mean}, or
-#' \code{median}.
-#' @return a graph object of class \code{dgr_graph}.
+#' Traverse from one or more selected edges onto adjacent, inward nodes
+#'
+#' From a graph object of class `dgr_graph` with an active selection of edges
+#' move with the edge direction to connected nodes, replacing the current edges
+#' in the selection with those nodes traversed to. An optional filter by node
+#' attribute can limit the set of nodes traversed to.
+#'
+#' This traversal function makes use of an active selection of edges. After the
+#' traversal, depending on the traversal conditions, there will either be a
+#' selection of nodes or no selection at all.
+#'
+#' Selections of edges can be performed using the following selection
+#' (`select_*()`) functions: [select_edges()], [select_last_edges_created()],
+#' [select_edges_by_edge_id()], or [select_edges_by_node_id()].
+#'
+#' Selections of edges can also be performed using the following traversal
+#' (`trav_*()`) functions: [trav_out_edge()], [trav_in_edge()],
+#' [trav_both_edge()], or [trav_reverse_edge()].
+#'
+#' @inheritParams render_graph
+#' @param conditions An option to use filtering conditions for the traversal.
+#' @param copy_attrs_from Providing an edge attribute name will copy those edge
+#'   attribute values to the traversed nodes. If the edge attribute already
+#'   exists, the values will be merged to the traversed nodes; otherwise, a new
+#'   node attribute will be created.
+#' @param copy_attrs_as If an edge attribute name is provided in
+#'   `copy_attrs_from`, this option will allow the copied attribute values to be
+#'   written under a different node attribute name. If the attribute name
+#'   provided in `copy_attrs_as` does not exist in the graph's ndf, the new node
+#'   attribute will be created with the chosen name.
+#' @param agg If an edge attribute is provided to `copy_attrs_from`, then an
+#'   aggregation function is required since there may be cases where multiple
+#'   edge attribute values will be passed onto the traversed node(s). To pass
+#'   only a single value, the following aggregation functions can be used:
+#'   `sum`, `min`, `max`, `mean`, or `median`.
+#'
+#' @return A graph object of class `dgr_graph`.
+#'
 #' @examples
 #' # Set a seed
+#' suppressWarnings(RNGversion("3.5.0"))
 #' set.seed(23)
 #'
 #' # Create a simple graph
@@ -77,12 +81,10 @@
 #'   join_node_attrs(df = df_nodes)
 #'
 #' # Show the graph's internal node data frame
-#' graph %>%
-#'   get_node_df()
+#' graph %>% get_node_df()
 #'
 #' # Show the graph's internal edge data frame
-#' graph %>%
-#'   get_edge_df()
+#' graph %>% get_edge_df()
 #'
 #' # Perform a simple traversal from the
 #' # edge `1`->`3` to the attached node
@@ -180,12 +182,10 @@
 #'   select_edges()
 #'
 #' # Show the graph's internal edge data frame
-#' graph %>%
-#'   get_edge_df()
+#' graph %>% get_edge_df()
 #'
 #' # Show the graph's internal node data frame
-#' graph %>%
-#'   get_node_df()
+#' graph %>% get_node_df()
 #'
 #' # Perform a traversal from the edges to
 #' # the central node (`1`) while also applying
@@ -200,14 +200,10 @@
 #'
 #' # Show the graph's internal node data frame
 #' # after this change
-#' graph %>%
-#'   get_node_df()
-#' @importFrom stats as.formula
-#' @importFrom dplyr filter distinct left_join right_join semi_join
-#' @importFrom dplyr select select_ rename group_by summarize_ everything
-#' @importFrom rlang enquo UQ get_expr
-#' @export trav_in_node
-
+#' graph %>% get_node_df()
+#'
+#' @import rlang
+#' @export
 trav_in_node <- function(graph,
                          conditions = NULL,
                          copy_attrs_from = NULL,
@@ -280,9 +276,6 @@ trav_in_node <- function(graph,
     }
   }
 
-  # Create bindings for specific variables
-  id <- type <- label <- to <- to.y <- NULL
-
   # Get the selection of edges
   starting_edges <- graph$edge_selection
 
@@ -307,10 +300,7 @@ trav_in_node <- function(graph,
     rlang::enquo(conditions) %>%
     rlang::get_expr())) {
 
-    valid_nodes <-
-      dplyr::filter(
-        .data = valid_nodes,
-        rlang::UQ(conditions))
+    valid_nodes <- dplyr::filter(.data = valid_nodes, !!conditions)
   }
 
   # If no rows returned, then there are no
@@ -348,7 +338,7 @@ trav_in_node <- function(graph,
       nodes %>%
       dplyr::rename(id = to.y) %>%
       dplyr::group_by(id) %>%
-      dplyr::summarize_(.dots = setNames(
+      dplyr::summarize_(.dots = stats::setNames(
         list(stats::as.formula(
           paste0("~", agg, "(", copy_attrs_from, ", na.rm = TRUE)"))),
         copy_attrs_from)) %>%
