@@ -2,7 +2,9 @@
 # Graph validation functions
 ###
 
-# Function to check whether a graph object is valid
+#' Check whether a graph object is valid
+#'
+#' @noRd
 graph_object_valid <- function(graph) {
 
   # Check for all component names to be present
@@ -37,38 +39,33 @@ graph_object_valid <- function(graph) {
   return(TRUE)
 }
 
-# Function to check whether a graph contains any nodes
+#' Check whether a graph contains any nodes
+#'
+#' @noRd
 graph_contains_nodes <- function(graph) {
 
-  if (node_count(graph) == 0) {
+  if (nrow(graph$nodes_df) == 0) {
     return(FALSE)
   } else {
     return(TRUE)
   }
 }
 
-# Function to check whether a graph contains any edges
+#' Check whether a graph contains any edges
+#'
+#' @noRd
 graph_contains_edges <- function(graph) {
 
-  if (edge_count(graph) == 0) {
+  if (nrow(graph$edges_df) == 0) {
     return(FALSE)
   } else {
     return(TRUE)
   }
 }
 
-# Function to check whether a graph contains a valid edge selection
-graph_contains_edge_selection <- function(graph) {
-
-  # Check if graph contains an edge selection
-  if (nrow(graph$edge_selection) > 0) {
-    return(TRUE)
-  } else {
-    return(FALSE)
-  }
-}
-
-# Function to check whether a graph contains a valid node selection
+#' Check whether a graph contains a valid node selection
+#'
+#' @noRd
 graph_contains_node_selection <- function(graph) {
 
   # Check if graph contains a node selection
@@ -79,10 +76,72 @@ graph_contains_node_selection <- function(graph) {
   }
 }
 
-# Function to replace the `node_selection` df with
-# different node ID values
-#' @importFrom tibble tibble as_tibble
-#' @importFrom dplyr bind_rows
+#' Check whether a graph contains a valid edge selection
+#'
+#' @noRd
+graph_contains_edge_selection <- function(graph) {
+
+  # Check if graph contains an edge selection
+  if (nrow(graph$edge_selection) > 0) {
+    return(TRUE)
+  } else {
+    return(FALSE)
+  }
+}
+
+#' Get a list of node/edge selection properties
+#'
+#' @noRd
+node_edge_selection_properties <- function(graph) {
+
+  # Determine if there is an existing
+  # selection of nodes
+  node_selection_available <-
+    ifelse(
+      graph_contains_node_selection(graph = graph), TRUE, FALSE)
+
+  # Determine if there is an existing
+  # selection of edges
+  edge_selection_available <-
+    ifelse(
+      graph_contains_edge_selection(graph = graph), TRUE, FALSE)
+
+  # Get the existing node/edge count
+  if (node_selection_available | edge_selection_available) {
+
+    selection_type <-
+      ifelse(node_selection_available, "node", "edge")
+
+    if (selection_type == "node") {
+      selection_count <- nrow(graph$node_selection)
+      selection_count_str <-
+        paste0(selection_count, " node", ifelse(selection_count > 1, "s", ""))
+
+    } else {
+
+      selection_count <- nrow(graph$edge_selection)
+      selection_count_str <-
+        paste0(selection_count, " edge", ifelse(selection_count > 1, "s", ""))
+    }
+
+  } else {
+
+    selection_type <- as.character(NA)
+    selection_count <- 0
+    selection_count_str <- "no nodes or edges"
+  }
+
+  list(
+    node_selection_available = node_selection_available,
+    edge_selection_available = edge_selection_available,
+    selection_type = selection_type,
+    selection_count = selection_count,
+    selection_count_str = selection_count_str)
+}
+
+#' Replace the `node_selection` df with different node ID values
+#'
+#' @noRd
 replace_graph_node_selection <- function(graph,
                                          replacement) {
 
@@ -92,7 +151,7 @@ replace_graph_node_selection <- function(graph,
   # Remove objects in `graph$node_selection`
   node_selection <-
     node_selection %>%
-    tibble::as_tibble()
+    dplyr::as_tibble()
 
   node_selection <-
     node_selection[-seq(1, nrow(node_selection)), 1] %>%
@@ -101,14 +160,13 @@ replace_graph_node_selection <- function(graph,
   # Add replacement to `graph$node_selection`
   node_selection %>%
     dplyr::bind_rows(
-      tibble::tibble(
+      dplyr::tibble(
         node = as.integer(replacement)))
 }
 
-# Function to replace the `edge_selection` df with
-# different node ID values
-#' @importFrom tibble tibble as_tibble
-#' @importFrom dplyr bind_rows
+#' Replace the `edge_selection` df with different edge ID values
+#'
+#' @noRd
 replace_graph_edge_selection <- function(graph,
                                          edge_id,
                                          from_node,
@@ -120,7 +178,7 @@ replace_graph_edge_selection <- function(graph,
   # Remove objects in `graph$edge_selection`
   edge_selection <-
     edge_selection %>%
-    tibble::as_tibble()
+    dplyr::as_tibble()
 
   edge_selection <-
     edge_selection[-seq(1, nrow(edge_selection)), 1] %>%
@@ -129,7 +187,7 @@ replace_graph_edge_selection <- function(graph,
   # Add replacement to `graph$edge_selection`
   edge_selection %>%
     dplyr::bind_rows(
-      tibble::tibble(
+      dplyr::tibble(
         edge = as.integer(edge_id),
         from = as.integer(from_node),
         to = as.integer(to_node)))
@@ -138,7 +196,7 @@ replace_graph_edge_selection <- function(graph,
 create_empty_nsdf <- function() {
 
   # Create empty `nsdf`
-  tibble::tibble(
+  dplyr::tibble(
     node = as.integer(NA))[-1, ] %>%
     as.data.frame(stringsAsFactors = FALSE)
 }
@@ -146,18 +204,20 @@ create_empty_nsdf <- function() {
 create_empty_esdf <- function() {
 
   # Create empty `esdf`
-  tibble::tibble(
+  dplyr::tibble(
     edge = as.integer(NA),
     from = as.integer(NA),
     to = as.integer(NA))[-1, ] %>%
     as.data.frame(stringsAsFactors = FALSE)
 }
 
-# Function to determine whether a node or edge
-# attribute has values that are all non-NA and
-# are unique
-#' @importFrom dplyr select_ distinct
+#' Is an attribute unique and fully free of `NA`s?
+#'
+#' This function determines whether a node or edge attribute has values that
+#' are all non-`NA` and are unique
+#'
 #' @importFrom magrittr not
+#' @noRd
 is_attr_unique_and_non_na <- function(graph,
                                       which_graph_df,
                                       attr) {
@@ -167,11 +227,15 @@ is_attr_unique_and_non_na <- function(graph,
   } else if (which_graph_df == "edf") {
     df <- graph$edges_df
   } else {
-    stop("The `which_graph_df` argument must be either `ndf` or `edf`.")
+    stop(
+      "The `which_graph_df` argument must be either `ndf` or `edf`.",
+      call. = FALSE)
   }
 
   if (!(attr %in% colnames(df))) {
-    stop("The `attr` provided is not available.")
+    stop(
+      "The `attr` provided is not available.",
+      call. = FALSE)
   }
 
   # Are all values not NA?
@@ -195,20 +259,29 @@ is_attr_unique_and_non_na <- function(graph,
 # Graph transformation functions
 ###
 
-# Function to take a graph object and labels for `from`
-# and `to` values, and, translate the `from`/`to` label
-# values to node ID values
+#' Transform `from` and `to` edge attributes
+#'
+#' This function takes a graph object and labels for `from` and `to` values and
+#' then translates the `from`/`to` label values to node ID values
+#'
+#' @noRd
 translate_to_node_id <- function(graph, from, to) {
 
   # Check that node labels are unique
   if (length(unique(graph$nodes_df$label)) !=
-      node_count(graph)) {
-    stop("You cannot use labels to form edges because they are not distinct")
+      count_nodes(graph)) {
+
+    stop(
+      "You cannot use labels to define edges because they are not distinct.",
+      call. = FALSE)
   }
 
   # No node labels can be empty
   if (any(graph$nodes_df$label == "")) {
-    stop("You cannot use labels to form edges if there are empty strings for labels")
+
+    stop(
+      "You cannot use labels to define edges since there are empty strings for labels.",
+      call. = FALSE)
   }
 
   # Create the `from_id` and `to_id` vectors
@@ -245,35 +318,45 @@ translate_to_node_id <- function(graph, from, to) {
 # Graph logging functions
 ###
 
-# Function to get the time of the graph function in
-# the user's locale
+#' Get the time of the graph function invocation
+#'
+#' @noRd
 graph_function_sys_time <- function() {
   return(Sys.time())
 }
 
-# Function to get the time difference from the start
-# of the function (relies on a call of the
-# `graph_function_sys_time()` function) to the time
-# of invoking this function
+#' Get the time taken for a graph function to execute
+#'
+#' This calculates the difference from the start of the function call (relies on
+#' a call of the `graph_function_sys_time()` function) to the time of invoking
+#' this function
+#'
+#' @noRd
 graph_function_duration <- function(start_time) {
   end_time <- Sys.time()
   time_diff_s <- (end_time - start_time)[[1]]
   return(time_diff_s)
 }
 
-# Function to add log line for a graph `action`
-#' @importFrom dplyr bind_rows
+#' Add a log line for a graph `action`
+#'
+#' @noRd
 add_action_to_log <- function(graph_log,
                               version_id,
                               function_used,
                               time_modified,
                               duration,
                               nodes,
-                              edges) {
+                              edges,
+                              d_n = 0,
+                              d_e = 0) {
 
   # Ensure that `time_modified` inherits from POSIXct
   if (inherits(time_modified, "POSIXct") == FALSE) {
-    stop("The `time_modified` value must inherit from POSIXct.")
+
+    stop(
+      "The `time_modified` value must inherit from POSIXct.",
+      call. = FALSE)
   }
 
   # Create a log line
@@ -285,14 +368,17 @@ add_action_to_log <- function(graph_log,
       duration = as.numeric(duration),
       nodes = as.integer(nodes),
       edges = as.integer(edges),
+      d_n = as.integer(d_n),
+      d_e = as.integer(d_e),
       stringsAsFactors = FALSE)
 
   # Append the log line to `graph_log`
   dplyr::bind_rows(graph_log, graph_log_line)
 }
 
-# Function to save the graph as an RDS file within
-# a subdirectory in the working directory
+#' Save the graph as an RDS file
+#'
+#' @noRd
 save_graph_as_rds <- function(graph) {
 
   # Construct a file name for the RDS
@@ -322,13 +408,92 @@ save_graph_as_rds <- function(graph) {
   saveRDS(graph, file = paste0(rds_dir_name, "/", rds_filename))
 }
 
+###
+# Selection helper functions
+###
+
+#' Get column names from a column selection statement
+#'
+#' @noRd
+get_col_selection <- function(col_selection_stmt) {
+
+  if (all(stringr::str_detect(
+    string = col_selection_stmt,
+    pattern = "^([a-zA-Z_\\.][a-zA-Z0-9_\\.]*?|`.*?`)$")) & length(col_selection_stmt) == 1) {
+
+    selection_type <- "single_column_name"
+
+    # Get the column names
+    column_selection <- col_selection_stmt
+
+  } else if (all(stringr::str_detect(
+    string = col_selection_stmt,
+    pattern = "(.* & ).*")) & length(col_selection_stmt) == 1) {
+
+    selection_type <- "column_names"
+
+    # Get the column names
+    column_selection <-
+      stringr::str_split(
+        string = col_selection_stmt,
+        pattern = " & ") %>%
+      unlist()
+
+  } else if (any(stringr::str_detect(
+    string = col_selection_stmt,
+    pattern = "^[0-9]*?:[0-9]*?$"))) {
+
+    selection_type <- "column_index_range"
+
+    # Get the column indices
+    column_selection <-
+      seq(
+        from = (stringr::str_split(
+          string = col_selection_stmt,
+          pattern = ":") %>%
+            unlist())[1] %>%
+          as.numeric(),
+        to = (stringr::str_split(
+          string = col_selection_stmt,
+          pattern = ":") %>%
+            unlist())[2] %>%
+          as.numeric())
+
+  } else if (any(
+    stringr::str_detect(
+      string = col_selection_stmt,
+      pattern = "^([a-zA-Z_\\.][a-zA-Z0-9_\\.]*?|`.*?`):([a-zA-Z_\\.][a-zA-Z0-9_\\.]*?|`.*?`)$"))
+  ) {
+
+    selection_type <- "column_range"
+
+    # Get the first and last column names
+    column_selection <-
+      c(
+        (stringr::str_split(
+          string = col_selection_stmt,
+          pattern = ":") %>%
+           unlist())[1],
+        (stringr::str_split(
+          string = col_selection_stmt,
+          pattern = ":") %>%
+           unlist())[2])
+  } else {
+    return(list())
+  }
+
+  list(
+    selection_type = selection_type,
+    column_selection = column_selection)
+}
+
 ###
 # Aesthetic attribute functions
 ###
 
-# Function to get the ideal contrasting text color
-# (black or white) given the fillcolor of a node
-#' @importFrom grDevices col2rgb
+#' Get the ideal contrasting text color given the fill color of a node
+#'
+#' @noRd
 contrasting_text_color <- function(background_color) {
 
   rgb_colors <-
@@ -355,32 +520,161 @@ contrasting_text_color <- function(background_color) {
   contrasting_color
 }
 
+###
+# Functions that help build info messages
+###
+
+#' Construct a consistent message string, passing it to `message()`
+#'
+#' @import glue
+#' @noRd
+emit_message <- function(fcn_name,
+                         message_body) {
+
+  glue::glue("`{fcn_name}()` INFO: {message_body}") %>%
+    as.character() %>%
+    message()
+}
+
+#' Construct a consistent message string, passing it to `warning()`
+#'
+#' @import glue
+#' @noRd
+emit_warning <- function(fcn_name,
+                         message_body) {
+
+  glue::glue("`{fcn_name}()` WARNING: {message_body}") %>%
+    as.character() %>%
+    warning()
+}
+
+#' Construct a consistent message string, passing it to `stop()`
+#'
+#' @import glue
+#' @noRd
+emit_error <- function(fcn_name,
+                       reasons) {
+
+  header_text <-
+      ifelse(length(reasons) > 1, "REASONS:\n", "REASON:\n")
+
+  if (length(reasons <= 5)) {
+
+    message_body <-
+      paste(paste0("* ", reasons), collapse = "\n")
+
+  } else {
+
+    excess_errors <- length(reasons) - 5
+
+    message_body <-
+      paste(paste0("* ", reasons[1:5]), collapse = "\n")
+
+    error_pl_str <-
+      ifelse(excess_errors == 1, "error", "errors")
+
+    excess_errors_str <-
+      glue::glue(
+        "* ... and {excess_errors} more {error_pl_str}") %>%
+      as.character()
+  }
+
+  glue::glue("`{fcn_name}()` {header_text}{message_body}") %>%
+    as.character() %>%
+    stop(call. = FALSE)
+}
+
+#' Get the calling function as a formatted character string
+#'
+#' @noRd
+get_calling_fcn <- function() {
+
+  calling_fcn <- deparse(sys.call(-1))
+
+  stringr::str_replace_all(
+    calling_fcn,
+    pattern = "([a-z0-9_]*)(.*)",
+    replacement = "\\1")
+}
+
 ###
 # Functions that produce useful vectors
 ###
 
-# Function that yields vector of node
-# creation function names
+
+#' Produce a vector of Graphviz graph attribute names
+#'
+#' @noRd
+gv_graph_attributes <- function() {
+
+  c("layout", "bgcolor", "rankdir",
+    "overlap", "outputorder", "fixedsize",
+    "mindist", "nodesep", "ranksep",
+    "stylesheet")
+}
+
+#' Produce a vector of Graphviz node attribute names
+#'
+#' @noRd
+gv_node_attributes <- function() {
+
+  c("shape", "style", "penwidth", "color", "fillcolor",
+    "fontname", "fontsize", "fontcolor", "image", "fa_icon",
+    "height", "width", "group",
+    "tooltip", "xlabel", "URL",
+    "distortion", "sides", "skew", "peripheries",
+    "gradientangle", "label", "fixedsize",
+    "labelloc", "margin", "orientation", "pos")
+}
+
+#' Produce a vector of Graphviz edge attribute names
+#'
+#' @noRd
+gv_edge_attributes <- function() {
+
+  c("style", "penwidth", "color", "arrowsize",
+    "arrowhead", "arrowtail",
+    "fontname", "fontsize", "fontcolor",
+    "len", "tooltip", "URL",
+    "label", "labelfontname", "labelfontsize",
+    "labelfontcolor", "labeltooltip", "labelURL",
+    "edgetooltip", "edgeURL",
+    "headtooltip", "headURL",
+    "headclip", "headlabel", "headport",
+    "tailtooltip", "tailURL",
+    "tailclip",  "taillabel", "tailport",
+    "dir", "decorate")
+}
+
+#' Produce a vector of node creation function names
+#'
+#' @noRd
 node_creation_functions <- function() {
 
   c("add_node", "add_n_nodes", "add_n_node_clones",
-    "add_n_nodes_ws", "add_node_df",
-    "add_nodes_from_df_cols",
+    "add_node_clones_ws", "add_n_nodes_ws",
+    "add_node_df", "add_nodes_from_df_cols",
     "add_nodes_from_table", "add_full_graph",
     "add_balanced_tree", "add_cycle",
-    "add_path", "add_prism", "add_star")
+    "add_path", "add_prism", "add_star",
+    "add_grid_2d", "add_grid_3d", "add_gnm_graph",
+    "add_gnp_graph", "add_pa_graph",
+    "add_smallworld_graph", "add_growing_graph",
+    "add_islands_graph")
 }
 
-# Function that yields vector of node
-# deletion function names
+#' Produce a vector of node deletion function names
+#'
+#' @noRd
 node_deletion_functions <- function() {
 
   c("create_subgraph_ws", "create_complement_graph",
     "delete_node", "delete_nodes_ws")
 }
 
-# Function that yields vector of edge
-# creation function names
+#' Produce a vector of edge creation function names
+#'
+#' @noRd
 edge_creation_functions <- function() {
 
   c("add_edge", "add_edge_clone", "add_edges_w_string",
@@ -388,20 +682,27 @@ edge_creation_functions <- function() {
     "add_reverse_edges_ws",
     "add_edges_from_table", "add_full_graph",
     "add_balanced_tree", "add_cycle",
-    "add_path", "add_prism", "add_star")
+    "add_path", "add_prism", "add_star",
+    "add_grid_2d", "add_grid_3d", "add_gnm_graph",
+    "add_gnp_graph", "add_pa_graph",
+    "add_smallworld_graph", "add_growing_graph",
+    "fully_connect_nodes_ws")
 }
 
-# Function that yields vector of edge
-# deletion function names
+#' Produce a vector of edge deletion function names
+#'
+#' @noRd
 edge_deletion_functions <- function() {
 
   c("delete_edge", "delete_edges_ws",
     "create_subgraph_ws", "create_complement_graph",
-    "delete_node", "delete_nodes_ws")
+    "delete_node", "delete_nodes_ws", "delete_loop_edges_ws",
+    "fully_disconnect_nodes_ws")
 }
 
-# Function that yields vector of graph
-# initializing function names
+#' Produce vector of graph initializing function names
+#'
+#' @noRd
 graph_init_functions <- function() {
 
   c("create_graph", "create_random_graph",
@@ -409,9 +710,9 @@ graph_init_functions <- function() {
     "import_graph")
 }
 
-# Function that to create a list of data frames
-# for functions that get node properties using
-# whole-graph methods
+#' Produce a list of data frames for functions that get node properties
+#'
+#' @noRd
 value_per_node_functions <- function() {
 
   list(
@@ -536,14 +837,11 @@ value_per_node_functions <- function() {
 }
 
 
-# Function to determine the `df_id` values
-# for a graph's internal ndf or edf
-#' @importFrom dplyr select filter pull
+#' Get the `df_id` values for a graph's internal NDF or EDF
+#'
+#' @noRd
 get_df_ids <- function(graph_df) {
 
-  # Create binding for a specific variable
-  df_id <- NULL
-
   if (nrow(graph_df) > 0) {
 
     if ("df_id" %in% colnames(graph_df)) {
@@ -562,15 +860,14 @@ get_df_ids <- function(graph_df) {
 }
 
 
-# Function to scavenge the graph$df_storage
-# list and remove any linked data frames if
-# the associated nodes or edges no longer exist
-#' @importFrom dplyr bind_rows filter select distinct pull
+#' Scavenge the `graph$df_storage` list
+#'
+#' This removes any linked data frames if the associated nodes or edges no
+#' longer exist.
+#'
+#' @noRd
 remove_linked_dfs <- function(graph) {
 
-  # Create bindings for specific variables
-  node_edge__ <- df_id__ <- df_id <- NULL
-
   if (is.null(graph$df_storage)) {
     return(graph)
   }
@@ -597,7 +894,7 @@ remove_linked_dfs <- function(graph) {
       dplyr::select(df_id__) %>%
       dplyr::distinct() %>%
       dplyr::pull(df_id__) %>%
-      setdiff(ndf_df_ids)
+      base::setdiff(ndf_df_ids)
 
     # If any stored data frames are associated
     # with edges that no longer exist, remove them
@@ -621,7 +918,7 @@ remove_linked_dfs <- function(graph) {
       dplyr::select(df_id__) %>%
       dplyr::distinct() %>%
       dplyr::pull(df_id__) %>%
-      setdiff(edf_df_ids)
+      base::setdiff(edf_df_ids)
 
 
     # If any stored data frames are associated
@@ -669,3 +966,101 @@ remove_linked_dfs <- function(graph) {
 
   graph
 }
+
+###
+# Functions for working with graph SVG output
+###
+
+#' Create a table of SVG attributes
+#'
+#' @noRd
+get_svg_tbl <- function(svg_vec) {
+
+  svg_tbl <-
+    dplyr::tibble(
+      index = integer(0), type = character(0), node_id = integer(0),
+      from = integer(0), to = integer(0))
+
+  for (i in seq(svg_vec)) {
+
+    line <- svg_vec[i]
+
+    if (grepl("^<\\?xml.*", line)) {
+      rec <- dplyr::tibble(index = i, type = "xml_declaration")
+    } else if (grepl("(^<!DOCTYPE.*|.*http://www.w3.org.*)", line)) {
+      rec <- dplyr::tibble(index = i, type = "doctype_declaration")
+    } else if (grepl("(<!-- Generated by|^ -->$)", line)) {
+      rec <- dplyr::tibble(index = i, type = "generator_comment")
+    } else if (grepl("<!-- Title:", line)) {
+      rec <- dplyr::tibble(index = i, type = "title_block")
+    } else if (grepl("^<svg", line)) {
+      rec <- dplyr::tibble(index = i, type = "svg") %>% dplyr::bind_cols(get_attr_tbl(line))
+    } else if (grepl(" viewBox", line)) {
+      rec <- dplyr::tibble(index = i, type = "viewbox_info")
+    } else if (grepl("^<g ", line)) {
+      rec <- dplyr::tibble(index = i, type = "g") %>% dplyr::bind_cols(get_attr_tbl(line))
+    } else if (grepl("^<title>", line)) {
+      rec <- dplyr::tibble(index = i, type = "title") %>% dplyr::bind_cols(get_inner_html(line))
+    } else if (grepl("^<polygon", line)) {
+      rec <- dplyr::tibble(index = i, type = "polygon") %>% dplyr::bind_cols(get_attr_tbl(line))
+    } else if (grepl("^<path", line)) {
+      rec <- dplyr::tibble(index = i, type = "path") %>% dplyr::bind_cols(get_attr_tbl(line))
+    } else if (grepl("^<ellipse", line)) {
+      rec <- dplyr::tibble(index = i, type = "ellipse") %>% dplyr::bind_cols(get_attr_tbl(line))
+    } else if (grepl("<!-- [0-9]*? -->", line)) {
+      node_id <- gsub("(<!-- | -->)", "", line) %>% as.integer()
+      rec <- dplyr::tibble(index = i, type = "node_block", node_id = node_id)
+    } else if (grepl("<!-- [0-9]*?&#45;&gt;[0-9]*? -->", line)) {
+      from_node_id <- gsub("(<!-- |?&#45;&gt;[0-9]*? -->)", "", line) %>% as.integer()
+      to_node_id <- gsub("(<!-- [0-9]*?&#45;&gt;| -->)", "", line) %>% as.integer()
+      rec <- dplyr::tibble(index = i, type = "edge_block", from = from_node_id, to = to_node_id)
+    } else if (grepl("<!-- [0-9]*?&#45;&#45;[0-9]*? -->", line)) {
+      from_node_id <- gsub("(<!-- |?&#45;&#45;[0-9]*? -->)", "", line) %>% as.integer()
+      to_node_id <- gsub("(<!-- [0-9]*?&#45;&#45;| -->)", "", line) %>% as.integer()
+      rec <- dplyr::tibble(index = i, type = "edge_block", from = from_node_id, to = to_node_id)
+    } else if (grepl("^<text ", line)) {
+      rec <- dplyr::tibble(index = i, type = "text") %>%
+        dplyr::bind_cols(get_attr_tbl(line)) %>%
+        dplyr::bind_cols(get_inner_html(line))
+    } else if (grepl("</g>", line)) {
+      rec <- dplyr::tibble(index = i, type = "g_close")
+    } else if (grepl("</svg>", line)) {
+      rec <- dplyr::tibble(index = i, type = "svg_close")
+    } else {
+      rec <- dplyr::tibble(index = i, type = "unknown")
+    }
+
+    svg_tbl <- dplyr::bind_rows(svg_tbl, rec)
+  }
+
+  svg_tbl %>% tidyr::fill(node_id)
+}
+
+#' Function to create a one-row table of attr-value pairs
+#'
+#' @noRd
+get_attr_tbl <- function(line) {
+
+  line <- gsub("<[a-z]*? ", "", line) %>% gsub("\"", "'", .) %>% gsub("(/>|>|>.*)", "", .)
+
+  el_attrs <-
+    strsplit(line, "' ") %>%
+    unlist() %>%
+    gsub("'", "", .) %>% strsplit("=")
+
+  stats::setNames(
+    sapply(el_attrs, `[[`, 2),
+    sapply(el_attrs, `[[`, 1)) %>%
+    as.list() %>%
+    dplyr::as_tibble()
+}
+
+#' Function to create a one-row, one-column table of inner HTML
+#'
+#' @noRd
+get_inner_html <- function(line) {
+
+  inner_html <- gsub("(^<.*?>|</.*?>)", "", line)
+
+  dplyr::tibble(inner_html = inner_html)
+}
